@@ -1,6 +1,7 @@
 # Orca
 #
 # Copyright 2005-2006 Google Inc.
+# Portions Copyright 2007, Sun Microsystems, Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -25,10 +26,10 @@ ACSS definitions into engine-specific markup codes.
 
 """
 
-__id__ = "$Id: acss.py 1680 2006-11-09 18:43:48Z wwalker $"
+__id__ = "$Id: acss.py 1973 2007-02-02 23:22:35Z wwalker $"
 __author__ = "T. V. Raman"
-__version__ = "$Revision: 1680 $"
-__date__ = "$Date: 2006-11-09 13:43:48 -0500 (Thu, 09 Nov 2006) $"
+__version__ = "$Revision: 1973 $"
+__date__ = "$Date: 2007-02-02 18:22:35 -0500 (Fri, 02 Feb 2007) $"
 __copyright__ = "Copyright (c) 2005 Google Inc."
 __license__ = "LGPL"
 
@@ -61,7 +62,18 @@ class ACSS(dict):
     def __init__(self,props={}):
         """Create and initialize ACSS structure."""
         for k in props:
-            if k in ACSS.settings: self[k] = props[k]
+            if k in ACSS.settings:
+                # Do a 'deep copy' of the family.  Otherwise,
+                # the new ACSS shares the actual data with the
+                # props passed in.  This can cause unexpected
+                # side effects.
+                #
+                if k == ACSS.FAMILY:
+                    self[k] = {}
+                    for j in props[k].keys():
+                        self[k][j] = props[k][j]
+                else:
+                    self[k] = props[k]
         self.updateName()
 
     def __setitem__ (self, key, value):
