@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2005-2006 Sun Microsystems Inc.
+# Copyright 2005-2007 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -25,9 +25,9 @@ operations on the Accessible object, such as invoking default actions or
 moving the text caret.
 """
 
-__id__        = "$Id: braille.py,v 1.73 2006/12/17 23:45:47 wwalker Exp $"
-__version__   = "$Revision: 1.73 $"
-__date__      = "$Date: 2006/12/17 23:45:47 $"
+__id__        = "$Id: braille.py 1995 2007-02-11 16:40:57Z wwalker $"
+__version__   = "$Revision: 1995 $"
+__date__      = "$Date: 2007-02-11 11:40:57 -0500 (Sun, 11 Feb 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -926,27 +926,59 @@ def setupKeyRanges(keys):
     if not brlAPIRunning:
         return
 
-    # First, start by ignoring everything.
-    #
-    everything=[0,
-                brlapi.KEY_FLAGS_MASK \
-                | brlapi.KEY_TYPE_MASK \
-                | brlapi.KEY_CODE_MASK]
-    brlAPI.ignoreKeyRange(everything)
+    try:
+        # First, start by ignoring everything.
+        #
+        brlAPI.ignoreKeys(brlapi.rangeType_all, [0])
 
-    # Next, enable cursor routing keys.
-    #
-    cursorRoutingKeys = [brlapi.KEY_CMD_ROUTE,
-                         brlapi.KEY_CMD_ROUTE | brlapi.KEY_CMD_ARG_MASK]
-    brlAPI.acceptKeyRange(cursorRoutingKeys)
+        # Next, enable cursor routing keys.
+        #
+        keySet = [brlapi.KEY_TYPE_CMD | brlapi.KEY_CMD_ROUTE]
 
-    # Finally, enable the commands we care about.
-    #
-    keySet = []
-    for key in keys:
-        keySet.append(brlapi.KEY_TYPE_CMD | key)
-    if len(keySet):
-        brlAPI.acceptKeySet(keySet)
+        # Finally, enable the commands we care about.
+        #
+        for key in keys:
+            keySet.append(brlapi.KEY_TYPE_CMD | key)
+
+        brlAPI.acceptKeys(brlapi.rangeType_command, keySet)
+
+        debug.println(debug.LEVEL_FINEST, "Using BrlAPI v0.5.0+")
+    except:
+        debug.printException(debug.LEVEL_FINEST)
+        try:
+            # Old, incompatible way that was in v3.8 devel, but
+            # changed prior to release.  We need this just in case
+            # people have not updated yet.
+
+            # First, start by ignoring everything.
+            #
+            brlAPI.ignoreKeyRange(0,
+                                  brlapi.KEY_FLAGS_MASK \
+                                  | brlapi.KEY_TYPE_MASK \
+                                  | brlapi.KEY_CODE_MASK)
+
+            # Next, enable cursor routing keys.
+            #
+            brlAPI.acceptKeyRange(brlapi.KEY_TYPE_CMD | brlapi.KEY_CMD_ROUTE,
+                                  brlapi.KEY_TYPE_CMD \
+                                  | brlapi.KEY_CMD_ROUTE \
+                                  | brlapi.KEY_CMD_ARG_MASK)
+
+            # Finally, enable the commands we care about.
+            #
+            keySet = []
+            for key in keys:
+                keySet.append(brlapi.KEY_TYPE_CMD | key)
+            if len(keySet):
+                brlAPI.acceptKeySet(keySet)
+
+            debug.println(debug.LEVEL_FINEST,
+                          "Using BrlAPI pre-release v0.5.0")
+        except:
+            debug.printException(debug.LEVEL_FINEST)
+            debug.println(
+                debug.LEVEL_WARNING,
+                "Braille module cannot listen for braille input events")
 
 def init(callback=None, tty=7):
     """Initializes the braille module, connecting to the BrlTTY driver.
