@@ -19,9 +19,9 @@
 
 """Provides the default implementation for flat review for Orca."""
 
-__id__        = "$Id: flat_review.py 1987 2007-02-07 21:27:28Z joanied $"
-__version__   = "$Revision: 1987 $"
-__date__      = "$Date: 2007-02-07 16:27:28 -0500 (Wed, 07 Feb 2007) $"
+__id__        = "$Id: flat_review.py 2090 2007-03-04 23:08:20Z wwalker $"
+__version__   = "$Revision: 2090 $"
+__date__      = "$Date: 2007-03-04 18:08:20 -0500 (Sun, 04 Mar 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -1008,7 +1008,7 @@ class Context:
                     debug.println(debug.LEVEL_WARNING,
                                   "flat_review.getShowingZones: " +
                                   "WARNING CHILD.PARENT != PARENT!!!")
-                elif child.state.count(atspi.Accessibility.STATE_SHOWING):
+                elif self.script.pursueForFlatReview(child):
                     zones.extend(self.getShowingZones(child))
 
         return zones
