@@ -39,9 +39,9 @@ Each mode is defined below. The 4 bits of information listed here are:
     actual symbol or be inserted before the symbol.
 """
 
-__id__        = "$Id: punctuation_settings.py 1529 2006-10-05 16:31:04Z wwalker $"
-__version__   = "$Revision: 1529 $"
-__date__      = "$Date: 2006-10-05 12:31:04 -0400 (Thu, 05 Oct 2006) $"
+__id__        = "$Id: punctuation_settings.py 2073 2007-03-01 17:20:32Z wwalker $"
+__version__   = "$Revision: 2073 $"
+__date__      = "$Date: 2007-03-01 12:20:32 -0500 (Thu, 01 Mar 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -69,7 +69,7 @@ __punctuation["?"] =  [ settings.PUNCTUATION_STYLE_ALL,  PUNCTUATION_INSERT ]
 __punctuation["\""] = [ settings.PUNCTUATION_STYLE_MOST, PUNCTUATION_REPLACE ]
 __punctuation["("] =  [ settings.PUNCTUATION_STYLE_MOST, PUNCTUATION_REPLACE ]
 __punctuation[")"] =  [ settings.PUNCTUATION_STYLE_MOST, PUNCTUATION_REPLACE ]
-__punctuation["-"] =  [ settings.PUNCTUATION_STYLE_MOST, PUNCTUATION_INSERT ]
+__punctuation["-"] =  [ settings.PUNCTUATION_STYLE_MOST, PUNCTUATION_REPLACE ]
 __punctuation["_"] =  [ settings.PUNCTUATION_STYLE_MOST, PUNCTUATION_REPLACE ]
 __punctuation[":"] =  [ settings.PUNCTUATION_STYLE_MOST, PUNCTUATION_INSERT ]
 __punctuation[";"] =  [ settings.PUNCTUATION_STYLE_MOST, PUNCTUATION_INSERT ]
