@@ -19,9 +19,9 @@
 
 """Provides a custom script for gcalctool."""
 
-__id__        = "$Id: gcalctool.py,v 1.13 2006/09/29 17:02:23 wwalker Exp $"
-__version__   = "$Revision: 1.13 $"
-__date__      = "$Date: 2006/09/29 17:02:23 $"
+__id__        = "$Id: gcalctool.py 1658 2006-11-03 21:18:21Z richb $"
+__version__   = "$Revision: 1658 $"
+__date__      = "$Date: 2006-11-03 16:18:21 -0500 (Fri, 03 Nov 2006) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -32,6 +32,7 @@ import orca.input_event as input_event
 import orca.orca_state as orca_state
 import orca.rolenames as rolenames
 import orca.speech as speech
+import orca.speechgenerator as speechgenerator
 import orca.util as util
 
 ########################################################################
@@ -40,6 +41,35 @@ import orca.util as util
 #                                                                      #
 ########################################################################
 
+class SpeechGenerator(speechgenerator.SpeechGenerator):
+    """Overrides _getSpeechForPushButton to handle 'unspeakable'
+    button labels displayed on the screen.
+    """
+    def __init__(self, script):
+        speechgenerator.SpeechGenerator.__init__(self, script)
+        
+    def _getSpeechForObjectName(self, obj):
+        """Gives preference to the object name versus what is being
+        displayed on the screen.  This helps accomodate the naming
+        hints being given to us by gcalctool for it's mathematical
+        operator buttons."""
+
+        if obj.role != rolenames.ROLE_PUSH_BUTTON:
+            return speechgenerator.SpeechGenerator._getSpeechForObjectName(\
+                self, obj)
+
+        if obj.name:
+            name = obj.name
+        else:
+            name = util.getDisplayedText(obj)
+
+        if name:
+            return [name]
+        elif obj.description:
+            return [obj.description]
+        else:
+            return []
+
 class Script(default.Script):
 
     def __init__(self, app):
@@ -55,6 +85,11 @@ class Script(default.Script):
 
         self._display = None
 
+    def getSpeechGenerator(self):
+        """Returns the speech generator for this script.
+        """
+        return SpeechGenerator(self)
+
     def onWindowActivated(self, event):
         """Called whenever one of gcalctool's toplevel windows is activated.
 
@@ -125,6 +160,7 @@ class Script(default.Script):
                                    input_event.KeyboardEvent)):
                 return
 
-            if (orca_state.lastInputEvent.event_string == "Return") \
+            if (orca_state.lastInputEvent.event_string == "space") \
+                   or (orca_state.lastInputEvent.event_string == "Return") \
                    or (orca_state.lastInputEvent.event_string == "="):
                 speech.speak(contents)
