@@ -18,8 +18,13 @@
 # Boston, MA 02111-1307, USA.
 
 """Custom script for gdmlogin - this makes sure the focused item is spoken
-when Orca starts.
-"""
+when Orca starts."""
+
+__id__        = "$Id: gdmlogin.py 1036 2006-06-10 00:54:48Z wwalker $"
+__version__   = "$Revision: 1036 $"
+__date__      = "$Date: 2006-06-09 20:54:48 -0400 (Fri, 09 Jun 2006) $"
+__copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
+__license__   = "LGPL"
 
 import orca.atspi as atspi
 import orca.default as default
