@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2005-2006 Sun Microsystems Inc.
+# Copyright 2005-2007 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -19,10 +19,10 @@
 
 """Provides various utility functions for Orca."""
 
-__id__        = "$Id: util.py,v 1.55 2006/12/15 18:25:11 lmonsanto Exp $"
-__version__   = "$Revision: 1.55 $"
-__date__      = "$Date: 2006/12/15 18:25:11 $"
-__copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
+__id__        = "$Id: util.py 2029 2007-02-17 01:53:35Z wwalker $"
+__version__   = "$Revision: 2029 $"
+__date__      = "$Date: 2007-02-16 20:53:35 -0500 (Fri, 16 Feb 2007) $"
+__copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 try:
@@ -53,6 +53,11 @@ import speechserver
 
 from orca_i18n import _ # for gettext support
 
+# Unicode currency symbols (populated by the getUnicodeCurrencySymbols()
+# routine).
+#
+_unicodeCurrencySymbols = []
+
 # Embedded object character used to indicate that an object is
 # embedded in a string.
 #
@@ -98,6 +103,8 @@ def isSameObject(obj1, obj2):
         while parent1 and parent2 and \
                 parent1.role == rolenames.ROLE_LABEL and \
                 parent2.role == rolenames.ROLE_LABEL:
+            if parent1.index != parent2.index:
+                return False
             parent1 = parent1.parent
             parent2 = parent2.parent
         if parent1 and parent2 and parent1 == parent2:
@@ -170,6 +177,45 @@ def __isLabeling(label, object):
 
     return False
 
+def getUnicodeCurrencySymbols():
+    """Return a list of the unicode currency symbols, populating the list
+    if this is the first time that this routine has been called.
+
+    Returns a list of unicode currency symbols.
+    """
+
+    global _unicodeCurrencySymbols
+
+    if not _unicodeCurrencySymbols:
+        _unicodeCurrencySymbols = [ \
+            u'\u0024',     # dollar sign
+            u'\u00A2',     # cent sign
+            u'\u00A3',     # pound sign
+            u'\u00A4',     # currency sign
+            u'\u00A5',     # yen sign
+            u'\u0192',     # latin small letter f with hook
+            u'\u060B',     # afghani sign
+            u'\u09F2',     # bengali rupee mark
+            u'\u09F3',     # bengali rupee sign
+            u'\u0AF1',     # gujarati rupee sign
+            u'\u0BF9',     # tamil rupee sign
+            u'\u0E3F',     # thai currency symbol baht
+            u'\u17DB',     # khmer currency symbol riel
+            u'\u2133',     # script capital m
+            u'\u5143',     # cjk unified ideograph-5143
+            u'\u5186',     # cjk unified ideograph-5186
+            u'\u5706',     # cjk unified ideograph-5706
+            u'\u5713',     # cjk unified ideograph-5713
+            u'\uFDFC',     # rial sign
+        ]
+
+        # Add 20A0 (EURO-CURRENCY SIGN) to 20B5 (CEDI SIGN)
+        #
+        for ordChar in range(ord(u'\u20A0'), ord(u'\u20B5') + 1):
+            _unicodeCurrencySymbols.append(unichr(ordChar))
+
+    return _unicodeCurrencySymbols
+
 def getDisplayedLabel(object):
     """If there is an object labelling the given object, return the
     text being displayed for the object labelling this object.
@@ -286,7 +332,7 @@ def __getDisplayedTextInComboBox(combo):
     textObj = None
     for i in range(0, combo.childCount):
         child = combo.child(i)
-        if child.role == rolenames.ROLE_TEXT:
+        if child and child.role == rolenames.ROLE_TEXT:
             textObj = child
 
     if textObj:
@@ -340,6 +386,32 @@ def getDisplayedText(obj):
     if obj.text:
         displayedText = obj.text.getText(0, -1)
 
+        # [[[WDW - HACK to account for things such as Gecko that want
+        # to use the EMBEDDED_OBJECT_CHARACTER on a label to hold the
+        # object that has the real accessible text for the label.  We
+        # detect this by the specfic case where the text for the
+        # current object is a single EMBEDDED_OBJECT_CHARACTER.  In
+        # this case, we look to the child for the real text.]]]
+        #
+        unicodeText = displayedText.decode("UTF-8")
+        if unicodeText \
+           and (len(unicodeText) == 1) \
+           and (unicodeText[0] == EMBEDDED_OBJECT_CHARACTER):
+            try:
+                displayedText = getDisplayedText(obj.child(0))
+            except:
+                debug.printException(debug.LEVEL_WARNING)
+        elif unicodeText:
+            # [[[TODO: HACK - Welll.....we'll just plain ignore any
+            # text with EMBEDDED_OBJECT_CHARACTERs here.  We still need a
+            # general case to handle this stuff and expand objects
+            # with EMBEDDED_OBJECT_CHARACTERs.]]]
+            #
+            for i in range(0, len(unicodeText)):
+                if unicodeText[i] == EMBEDDED_OBJECT_CHARACTER:
+                    displayedText = None
+                    break
+
     if (not displayedText) or (len(displayedText) == 0):
         displayedText = obj.name
 
@@ -368,6 +440,24 @@ def getRealActiveDescendant(obj):
     manages its descendants.
     """
 
+    # If obj is a table cell and all of it's children are table cells
+    # (probably cell renderers), then return the first child which has
+    # a non zero length text string. If no such object is found, just
+    # fall through and use the default approach below. See bug #376791
+    # for more details.
+    #
+    if obj.role == rolenames.ROLE_TABLE_CELL and obj.childCount:
+        nonTableCellFound = False
+        for i in range (0, obj.childCount):
+            if obj.child(i).role != rolenames.ROLE_TABLE_CELL:
+                nonTableCellFound = True
+        if not nonTableCellFound:
+            for i in range (0, obj.childCount):
+                if obj.child(i).text:
+                    text = obj.child(i).text.getText(0, -1)
+                    if len(text) != 0:
+                        return obj.child(i)
+
     # [[[TODO: WDW - this is an odd hacky thing I've somewhat drawn
     # from Gnopernicus.  The notion here is that we get an active
     # descendant changed event, but that object tends to have children
@@ -601,6 +691,8 @@ def _addRepeatSegment(segment, line, respectPunctuation=True):
            or (isPunctChar and (style <= level)):
             repeatChar = chnames.getCharacterName(segment[0])
             line += _(" %d %s characters ") % (count, repeatChar)
+        else:
+            line += segment
     else:
         line += segment
 
@@ -801,21 +893,50 @@ def getTextLineAtCaret(obj):
     if not text:
         return ["", 0, 0]
 
+    # The caret might be positioned at the very end of the text area.
+    # In these cases, calling text.getTextAtOffset on an offset that's
+    # not positioned to a character can yield unexpected results.  In
+    # particular, we'll see the Gecko toolkit return a start and end
+    # offset of (0, 0), and we'll see other implementations, such as
+    # gedit, return reasonable results (i.e., gedit will give us the
+    # last line).
+    #
+    # In order to accommodate the differing behavior of different
+    # AT-SPI implementations, we'll make sure we give getTextAtOffset
+    # the offset of an actual character.  Then, we'll do a little check
+    # to see if that character is a newline - if it is, we'll treat it
+    # as the line.
+    #
     if text.caretOffset == text.characterCount:
         caretOffset = max(0, text.caretOffset - 1)
+        character = text.getText(caretOffset, caretOffset + 1).decode("UTF-8")
     else:
         caretOffset = text.caretOffset
+        character = None
 
-    # Get the line containing the caret
-    #
-    [string, startOffset, endOffset] = text.getTextAtOffset(
-        caretOffset, atspi.Accessibility.TEXT_BOUNDARY_LINE_START)
+    if (text.caretOffset == text.characterCount) \
+        and (character == "\n"):
+        content = ""
+        startOffset = caretOffset
+    else:
+        # Get the line containing the caret.  [[[TODO: HACK WDW - If
+        # there's only 1 character in the string, well, we get it.  We
+        # do this because Gecko's implementation of getTextAtOffset
+        # is broken if there is just one character in the string.]]]
+        #
+        if (text.characterCount == 1):
+            string = text.getText(caretOffset, caretOffset + 1)
+            startOffset = caretOffset
+            endOffset = caretOffset + 1
+        else:
+            [string, startOffset, endOffset] = text.getTextAtOffset(
+                caretOffset, atspi.Accessibility.TEXT_BOUNDARY_LINE_START)
 
-    # Sometimes we get the trailing line-feed-- remove it
-    #
-    content = string.decode("UTF-8")
-    if content[-1:] == "\n":
-        content = content[:-1]
+        # Sometimes we get the trailing line-feed-- remove it
+        #
+        content = string.decode("UTF-8")
+        if content[-1:] == "\n":
+            content = content[:-1]
 
     return [content.encode("UTF-8"), text.caretOffset, startOffset]
 
